<?php

if(!defined('ABSPATH'))
{
	die('Sorry we can\'t cater you, you tried to get in from the wrong way');
}

add_action('plugin_loaded', 'sharekar_plugin_main');

function sharekar_activation()
{
	
	$version = get_option('sharekar_version');
	
	if(SHAREKAR_VERSION != $version) {
		sharekar_create_meta_table();
	}
	
	update_option('sharekar_version',  SHAREKAR_VERSION);

}

// Initiates when plugin is fully loaded
function sharekar_plugin_main()
{
	global $sharekar;
	
	sharekar_activation();

	$sharekar = get_option('sharekar_settings');
	
	if(is_admin())
	{
		add_action('admin_menu', 'sharekar_admin_menu');
		add_action('admin_init', 'sharekar_adding_settings');
		add_action('admin_enqueue_scripts', 'sharekar_load_settings_script');
		add_action('enqueue_block_editor_assets', 'sharekar_add_gut_block');
	} else {
		sharekar_front();
	}
}

add_action('init', 'sharekar_register_blocks');

//register and render gutenberg blocks
function sharekar_register_blocks() {

	global $sharekar;

	register_block_type(
		'sharekar/clicktotweet',
		array(
			'attributes' => array(
				'tweet' => array(
					'type' => 'string'
				),
				'bg_color' => array(
					'type' =>  'string',
				),
				'color' => array(
					'type' => 'string',
				),
			),
			'render_callback' => 'sharekar_click_to_tweet_block',
		)
	);
}

// Create the meta table
function sharekar_create_meta_table() {
	global $wpdb;

	$charset_collate = $wpdb->get_charset_collate();

	$sql = "CREATE TABLE {$wpdb->prefix}sharekar_meta (
		id BIGINT(20) NOT NULL AUTO_INCREMENT,
		post_id BIGINT(20),
		meta_key VARCHAR(255) DEFAULT '' NOT NULL,
		meta_value LONGTEXT,
		PRIMARY KEY (id)
	) $charset_collate;";

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);
}

function sharekar_click_to_tweet_block($attr)
{
	include_once SHAREKAR_DIR . '/click_to_tweet.php';
	return sharekar_click_to_tweet_init($attr);
}

function sharekar_add_gut_block() {
    wp_enqueue_script('sharekar_click_to_tweet', plugins_url('/js/block.js', __FILE__), array('wp-blocks', 'wp-element', 'wp-i18n'), SHAREKAR_VERSION, true);
}

function sharekar_load_settings_script()
{
	wp_enqueue_script('sharekar_settings', plugins_url('/js/settings.js', __FILE__), array('jquery', 'jquery-ui-sortable'));
}

function sharekar_adding_settings()
{
	include_once SHAREKAR_DIR . '/settings.php';
}

add_action( 'admin_enqueue_scripts', 'sharekar_enqueue_scripts');
add_action('wp_enqueue_scripts', 'sharekar_front_scripts');

function sharekar_admin_menu()
{
	add_menu_page('ShareKar Settings', 'ShareKar', 'activate_plugins', 'sharekar', 'sharekar_settings', ' dashicons-share');
	
	add_submenu_page('sharekar', 'Settings', 'Settings', 'activate_plugins', 'sharekar', 'sharekar_settings');
	
	add_submenu_page('sharekar', 'Web Share', 'Web Share <span style="padding: 1px 3px; line-height: 1.5; background-color:red; color:white; border-radius:1px; font-size:12px;">New</span>', 'activate_plugins', 'sharekar_webshare','sharekar_webshare_settings');
}

function sharekar_enqueue_scripts($hook)
{
	if(strpos('sharekar', $hook) !== 0){
		return;
	}

	// Color picker CSS
	wp_enqueue_style('wp-color-picker');
}

function sharekar_front_scripts()
{	
	$sharekar_webshare = get_option('sharekar_webshare');

	if(is_admin() || empty($sharekar_webshare['enable_webshare']) || empty(sharekar_can_webshare())){
		return;
	}

	wp_enqueue_script('sharekar_webshare', SHAREKAR_PLUGIN_URL . '/js/web-share.js', [], SHAREKAR_VERSION, true);
	
	
}

// All the code required for the admin settings page
function sharekar_settings()
{
	global $sharekar;
	include_once SHAREKAR_DIR . '/settings-view.php';
}

function sharekar_webshare_settings()
{
	global $sharekar;
	include_once SHAREKAR_DIR . '/web-share.php';
}

// All the code that will be displayed when end user will be using the website.
function sharekar_front()
{
	global $sharekar;
	
	include_once SHAREKAR_DIR . '/front.php';
	
}



?>