<?php

if( !defined('ABSPATH') )
{
	die('You are not allowed here');
}

$GLOBALS['sharekar_webshare'] = get_option('sharekar_webshare');

function sharekar_sanitize_webshare($val){
	if(is_array($val)){
		return map_deep($val, 'sanitize_text_field');
	}
	
	return sanitize_text_field($val);
}

add_settings_field(
	'sharekar_enable_webshare',
	esc_attr__( 'Enable WebShare', 'sharekar' ),
	'sharekar_enable_webshare_field',
	'sharekar_webshare',
	'sharekar-webshare-options',
	array(
		'type'         => 'checkbox',
		'option_group' => 'sharekar-webshare',
		'option_name'  => 'sharekar_webshare',
		'name'         => 'enable_webshare',
		'label_for'    => 'sharekar_enable_webshare_field',
		'description'  => esc_attr__( 'Enable Webshare', 'sharekar' ),
	)
);

add_settings_field(
	'sharekar_btn_color',
	esc_attr__( 'Select Button Color', 'sharekar' ),
	'sharekar_btn_color_field',
	'sharekar_webshare',
	'sharekar-webshare-options',
	array(
		'type'         => 'color',
		'option_group' => 'sharekar-webshare',
		'option_name'  => 'sharekar_webshare',
		'name'         => 'webshare_bg_color',
		'label_for'    => 'sharekar_btn_color_field',
		'description'  => esc_attr__( 'Set Button Color According to your theme', 'sharekar' ),
	)
);

add_settings_field(
	'sharekar_button_position',
	esc_attr__( 'Button Position', 'sharekar' ),
	'sharekar_webshare_position_field',
	'sharekar_webshare',
	'sharekar-webshare-options',
	array(
		'type'         => 'select',
		'option_group' => 'sharekar-webshare',
		'option_name'  => 'sharekar_webshare',
		'name'         => 'webshare_position',
		'label_for'    => 'sharekar_webshare_position_field',
		'description'  => esc_attr__( 'Select the location where you want to show the button', 'sharekar' ),
	)
);

add_settings_field(
	'sharekar_position_bottom',
	esc_attr__( 'Position From Bottom', 'sharekar' ),
	'sharekar_webshare_bottom_field',
	'sharekar_webshare',
	'sharekar-webshare-options',
	array(
		'type'         => 'select',
		'option_group' => 'sharekar-webshare',
		'option_name'  => 'sharekar_webshare',
		'name'         => 'position_bottom',
		'label_for'    => 'sharekar_webshare_bottom_field',
		'description'  => esc_attr__( 'Position of button from bottom', 'sharekar' ),
	)
);

add_settings_field(
	'sharekar_position_left',
	esc_attr__( 'Position from left/right', 'sharekar' ),
	'sharekar_webshare_left_field',
	'sharekar_webshare',
	'sharekar-webshare-options',
	array(
		'type'         => 'select',
		'option_group' => 'sharekar-webshare',
		'option_name'  => 'sharekar_webshare',
		'name'         => 'position_left',
		'label_for'    => 'sharekar_webshare_left_field',
		'description'  => esc_attr__( 'Position of button from left or right', 'sharekar' ),
	)
);

add_settings_field(
	'sharekar_webshare_text',
	esc_attr__( 'Button Text', 'sharekar' ),
	'sharekar_webshare_text_field',
	'sharekar_webshare',
	'sharekar-webshare-options',
	array(
		'type'         => 'text',
		'option_group' => 'sharekar-webshare',
		'option_name'  => 'sharekar_webshare',
		'name'         => 'webshare_text',
		'label_for'    => 'sharekar_webshare_text_field',
		'description'  => esc_attr__( 'Text to show besides the Icon, Text will not be visible on Mobile devices. Set this field "nil" if you dont want to have any text', 'sharekar' ),
	)
);

add_settings_field(
	'sharekar_webshare_post_type',
	esc_attr__( 'Post Types', 'sharekar' ),
	'sharekar_webshare_post_type_field',
	'sharekar_webshare',
	'sharekar-webshare-options',
	array(
		'type'         => 'checkbox',
		'option_group' => 'sharekar-webshare',
		'option_name'  => 'sharekar_webshare',
		'name'         => 'webshare_post_type',
		'label_for'    => 'sharekar_webshare_post_type',
		'description'  => esc_attr__( 'Post types on which the Web Share button should be shown', 'sharekar' ),
	)
);

add_settings_field(
	'sharekar_webshare_radius',
	esc_attr__( 'Button Radius', 'sharekar' ),
	'sharekar_webshare_radius_field',
	'sharekar_webshare',
	'sharekar-webshare-options',
	array(
		'type'         => 'radio',
		'option_group' => 'sharekar-webshare',
		'option_name'  => 'sharekar_webshare',
		'name'         => 'webshare_radius',
		'label_for'    => 'sharekar_webshare_radius_field',
		'description'  => esc_attr__( 'Select the radius of the Webshare button', 'sharekar' ),
	)
);


function sharekar_webshare_section()
{
	//
}

function sharekar_enable_webshare_field($args)
{
	global $sharekar_webshare;
	
	$checked = '';
	if(isset($sharekar_webshare[$args['name']]))
	{
		$checked = 'checked';
	}
	echo '<input type="checkbox" id="'.esc_attr($args['label_for']).'" name="'.esc_attr($args['option_name'].'['. $args['name']) . ']" '.$checked.'>';
	
	if(!empty($args['description'])){
		echo '<p class="description">'. esc_html($args['description']) . '</p>';
	}
}

function sharekar_btn_color_field($args)
{
	global $sharekar_webshare;
	
	echo '<input type="text" class="sharekar-colorpicker" id="'.esc_attr($args['label_for']).'" name="'.esc_attr($args['option_name'].'['. $args['name']) . ']" value="'.(!empty($sharekar_webshare[$args['name']]) ? esc_attr($sharekar_webshare[$args['name']]) : '#2271b1') . '">';
	
	if(!empty($args['description'])){
		echo '<p class="description">'. esc_html($args['description']) . '</p>';
	}
}

function sharekar_webshare_position_field($args)
{
	global $sharekar_webshare;
	
	$opts = array('left' => esc_html__('Bottom Left', 'sharekar'), 'right' => esc_html__('Bottom Right', 'sharekar'));
	
	echo '<select id="'.esc_attr($args['label_for']).'" name="'.esc_attr($args['option_name']. '[' .$args['name']).']" value="'.(!empty($sharekar_webshare[$args['name']]) ? esc_attr($sharekar_webshare[$args['name']]) : null).'">';
	
	foreach($opts as $key => $opt)
	{
		$selected = '';
		
		if(empty($sharekar_webshare[$args['name']]) && $key === 'right')
		{
			$selected = 'selected';
		}
		
		if(!empty($sharekar_webshare[$args['name']]) && $sharekar_webshare[$args['name']] === $key)
		{
			$selected = 'selected';
		}
		echo '<option value="'.esc_attr($key).'" '.esc_attr($selected).'>'.esc_html($opt).'</option>';
	}
	
	
	echo '</select>';
	
	if(!empty($args['description'])){
		echo '<p class="description">'. esc_html($args['description']) . '</p>';
	}
}

function sharekar_webshare_bottom_field($args)
{
	global $sharekar_webshare;
	
	echo '<input type="text" id="'.esc_attr($args['label_for']).'" name="'.esc_attr($args['option_name'].'['. $args['name']) . ']" value="'.(!empty($sharekar_webshare[$args['name']]) ? esc_attr($sharekar_webshare[$args['name']]) : 5) . '">';
	
	if(!empty($args['description'])){
		echo '<p class="description">'. esc_html($args['description']) . '</p>';
	}
}

function sharekar_webshare_left_field($args)
{
	global $sharekar_webshare;
	
	echo '<input type="text" id="'.esc_attr($args['label_for']).'" name="'.esc_attr($args['option_name'].'['. $args['name']) . ']" value="'.(!empty($sharekar_webshare[$args['name']]) ? esc_attr($sharekar_webshare[$args['name']]) : 5) . '">';
	
	if(!empty($args['description'])){
		echo '<p class="description">'. esc_html($args['description']) . '</p>';
	}
}

function sharekar_webshare_text_field($args)
{
	global $sharekar_webshare;

	echo '<input type="text" id="'.esc_attr($args['label_for']).'" name="'.esc_attr($args['option_name'].'['. $args['name']) . ']" value="'.(!empty($sharekar_webshare[$args['name']]) ? esc_attr($sharekar_webshare[$args['name']]) : 'Share') . '">';
	
	if(!empty($args['description'])){
		echo '<p class="description">'. esc_html($args['description']) . '</p>';
	}
}

function sharekar_webshare_post_type_field($args)
{
	global $sharekar_webshare;

	$opts = array('homepage' => 'Homepage', 'posts' => 'Posts', 'page' => 'Page');
	
	foreach($opts as $key =>$s){
		$checked = '';
		
		if(isset($sharekar_webshare[$args['name']]) && in_array($key, $sharekar_webshare[$args['name']]))
		{
			$checked = 'checked';
		}
		
		echo '<input type="checkbox" name="'.esc_attr($args['option_name'].'['. $args['name']).'][]" value="'.esc_attr($key).'" '.esc_attr($checked).'/>'.esc_attr($s) . '<br/>';
	}
	echo '</ul>';
	
	if(!empty($args['description'])){
		echo '<p class="description">'. esc_html($args['description']) . '</p>';
	}
}

function sharekar_webshare_radius_field($args)
{
	global $sharekar_webshare;

	$opts = array('flat' => 'Flat', 'rounded' => 'Rounded', 'circular' => 'Circular');

	foreach($opts as $key => $opt)
	{
		$checked = '';
		if(empty($sharekar_webshare[$args['name']]) && $key === 'rounded'){
			$checked = 'checked';
		}
		
		if(!empty($sharekar_webshare[$args['name']]) && $sharekar_webshare[$args['name']] === $key)
		{
			$checked = 'checked';
		}
		
		echo '<input type="radio" id="'.esc_attr($args['label_for']).'" name="'.esc_attr($args['option_name']. '[' .$args['name']).']" value="'.esc_attr($key).'" '.esc_attr($checked).'/>'.esc_html($opt).'<br/>';
	}
	
	if(!empty($args['description'])){
		echo '<p class="description">'. esc_html($args['description']) . '</p>';
	}
}


echo '<h1>Web Share</h1>
	<p>Web Share is a way to use native share capabilities of the Operating System\'s Share feature. To simplify it is a way to use your device\'s share options<br/> 
	<strong style="color:red;">Note:</strong> This feature Works only if your site has https, it wont work if your website dosen\'t have https</p>
	';
	
settings_errors();

echo '<form method="post" action="options.php" style="margin-top:30px">';
settings_fields('sharekar-webshare');
do_settings_sections('sharekar_webshare');
submit_button();

echo '</form>';